==> haskell-configurator-pg-0.2.9-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-configurator-pg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 configurator-pg
version:              0.2.9
visibility:           public
id:                   configurator-pg-0.2.9-BXLWl4h0uV65I6VNru7kTL
key:                  configurator-pg-0.2.9-BXLWl4h0uV65I6VNru7kTL
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2011-2014 Bryan O'\''Sullivan
    Copyright 2015-2016 Leon P Smith
    Copyright 2019-2022 Robert Vollmert

maintainer:           rob@vllmrt.net
author:               Robert Vollmert
homepage:             https://github.com/robx/configurator-pg
synopsis:             Reduced parser for configurator-ng config files
description:
    This module provides a simplified and updated interface to the
    configuration file format of
    <https://hackage.haskell.org/package/configurator configurator> and
    <https://hackage.haskell.org/package/configurator-ng configurator-ng>.
    Its aim is primarily to allow updating programs that depend on
    configurator-ng to new versions of GHC without changing the
    configuration file format.

category:             Configuration, Data
abi:                  c80d0480ade1e523bf6d8bcb43c91735
exposed:              True
exposed-modules:      Data.Configurator
hidden-modules:
    Data.Configurator.Load Data.Configurator.Parser
    Data.Configurator.Syntax Data.Configurator.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/configurator-pg-0.2.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/configurator-pg-0.2.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configurator-pg
hs-libraries:         HSconfigurator-pg-0.2.9-BXLWl4h0uV65I6VNru7kTL
depends:
    base-4.16.4.0 containers-0.6.5.1
    megaparsec-9.6.1-7WPy93vP8bY6Hp5k3jEfIt
    protolude-0.3.4-D1VQqEs8LBFpQdycuDixc
    scientific-0.3.7.0-7nXcZobZD337Jkf1NR7gHa text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-configurator-pg/html/configurator-pg.haddock

haddock-html:         /usr/share/doc/haskell-configurator-pg/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configurator-pg-0.2.9-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-configurator-pg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 configurator-pg
version:              0.2.9
visibility:           public
id:                   configurator-pg-0.2.9-ETMBtxJwajcBVbVeyIoTJi
key:                  configurator-pg-0.2.9-ETMBtxJwajcBVbVeyIoTJi
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2011-2014 Bryan O'\''Sullivan
    Copyright 2015-2016 Leon P Smith
    Copyright 2019-2022 Robert Vollmert

maintainer:           rob@vllmrt.net
author:               Robert Vollmert
homepage:             https://github.com/robx/configurator-pg
synopsis:             Reduced parser for configurator-ng config files
description:
    This module provides a simplified and updated interface to the
    configuration file format of
    <https://hackage.haskell.org/package/configurator configurator> and
    <https://hackage.haskell.org/package/configurator-ng configurator-ng>.
    Its aim is primarily to allow updating programs that depend on
    configurator-ng to new versions of GHC without changing the
    configuration file format.

category:             Configuration, Data
abi:                  a501f04bcaa1b43d1ea5ee885b66a0a4
exposed:              True
exposed-modules:      Data.Configurator
hidden-modules:
    Data.Configurator.Load Data.Configurator.Parser
    Data.Configurator.Syntax Data.Configurator.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/configurator-pg-0.2.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/configurator-pg-0.2.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configurator-pg
hs-libraries:         HSconfigurator-pg-0.2.9-ETMBtxJwajcBVbVeyIoTJi
depends:
    base-4.16.4.0 containers-0.6.5.1
    megaparsec-9.6.1-4ddqmfzWc8oK1e0EydsIQd
    protolude-0.3.4-1J6m5AwiuqN9CEYTHS338T
    scientific-0.3.7.0-E54j5jp9j9XA8rATol4HF1 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-configurator-pg/html/configurator-pg.haddock

haddock-html:         /usr/share/doc/haskell-configurator-pg/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
